VehicleConfig class

Configuration for vehicle appearance and behavior

Constructors

VehicleConfig({required Color primaryColor, double size = 20.0, VehicleDirection direction = VehicleDirection.north, bool isFlashing = false, bool isCrashed = false, bool showEffects = true, double animationSpeed = 1.0})
const

Properties

animationSpeed double
Animation speed multiplier for effects (1.0 = normal speed)
final
direction VehicleDirection
Direction the vehicle is facing
final
hashCode int
The hash code for this object.
no setterinherited
isCrashed bool
Whether the vehicle appears crashed (red color, sparks)
final
isFlashing bool
Whether emergency lights should be flashing (ambulance/police)
final
primaryColor Color
Primary color of the vehicle body
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showEffects bool
Whether to show special effects (exhaust, stop signs, etc.)
final
size double
Size of the vehicle (width/height will be calculated proportionally)
final

Methods

copyWith({Color? primaryColor, double? size, VehicleDirection? direction, bool? isFlashing, bool? isCrashed, bool? showEffects, double? animationSpeed}) VehicleConfig
Create a copy with modified properties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited