VehicleType enum

Types of vehicles available in the Tuesdae Assets package

Inheritance
Available extensions

Values

regular → const VehicleType

Standard passenger car

ambulance → const VehicleType

Emergency ambulance with flashing lights and medical cross

police → const VehicleType

Police car with flashing lights and badge

tractor → const VehicleType

Agricultural tractor with treads and exhaust smoke

schoolBus → const VehicleType

School bus with stop sign and safety lights

impatient → const VehicleType

Impatient car (regular car with attitude)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VehicleType>
A constant List of the values in this enum, in order of their declaration.