VehiclePresets class
Preset vehicle configurations for common use cases
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- activePolice → const VehicleConfig
- Active police car with flashing lights
- crashedCar → const VehicleConfig
- Crashed vehicle with damage effects
- emergencyAmbulance → const VehicleConfig
- Emergency ambulance with flashing lights
- farmTractor → const VehicleConfig
- Slow-moving tractor with exhaust
- safetyBus → const VehicleConfig
- School bus with safety features
- standardCar → const VehicleConfig
- Standard blue car facing north